| Title: | Rank Distance Correlation Coefficient |
|---|---|
| Description: | The rank distance correlation <doi:10.1080/01621459.2020.1782223> is computed. Included also is a function to perform permutation based testing. |
| Authors: | Michail Tsagris [aut, cre] |
| Maintainer: | Michail Tsagris <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.1 |
| Built: | 2026-05-24 07:15:51 UTC |
| Source: | https://github.com/cran/rdcor |
The rank distance correlation of Shi H., Drton M. and Han F. (2022) is computed. Included also is a function to perform permutation based testing.
| Package: | rdcor | |
| Type: | Package | |
| Version: | 1.1 | |
| Date: | 2026-03-25 | |
| License: | GPL-2 |
Michail Tsagris [email protected].
Michail Tsagris [email protected].
Shi H., Drton M. and Han F. (2022). Distribution-free consistent independence tests via center-outward ranks and signs. Journal of the American Statistical Association, 117(537): 395–410.
Zhang Q. (2025). On the connections between Chatterjee's correlation and rank distance correlation. Journal of Nonparametric Statistics, 1–18.
Permutation-based hypothesis testing for the rank distance correlation.
rdcor.test(y, x, B = 499)rdcor.test(y, x, B = 499)
y |
A numerical vector. |
x |
A numerical vector or a numerical matrix. |
B |
The number of permutations to implement. |
Permutation-based hypothesis testing between y and x or between y and each column of x is performed.
If x is a vector a vector with the rank distance correlation and the permuation-based p-value. If x is a matrix, this returns a matrix with two columns: the rank distance correlation and the permutation-based p-value.
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Shi H., Drton M. and Han F. (2022). Distribution-free consistent independence tests via center-outward ranks and signs. Journal of the American Statistical Association, 117(537): 395–410.
Zhang Q. (2025). On the connections between Chatterjee's correlation and rank distance correlation. Journal of Nonparametric Statistics, 1–18.
y <- iris[, 1] x <- matrix( rnorm(150 * 10), ncol = 10 ) rdcor.test(y, x)y <- iris[, 1] x <- matrix( rnorm(150 * 10), ncol = 10 ) rdcor.test(y, x)
Rank distance correlation.
rdcor(y, x)rdcor(y, x)
y |
A numerical vector. |
x |
A numerical vector or a numerical matrix. |
This computes the rank distance correlation between y and x, or between y and each column of x.
A vector with the rank distance correlation().
Michail Tsagris.
R implementation and documentation: Michail Tsagris [email protected].
Shi H., Drton M. and Han F. (2022). Distribution-free consistent independence tests via center-outward ranks and signs. Journal of the American Statistical Association, 117(537): 395–410.
Zhang Q. (2025). On the connections between Chatterjee's correlation and rank distance correlation. Journal of Nonparametric Statistics, 1–18.
y <- iris[, 1] x <- matrix( rnorm(150 * 10), ncol = 10 ) rdcor(y, x)y <- iris[, 1] x <- matrix( rnorm(150 * 10), ncol = 10 ) rdcor(y, x)
Rank distance correlation matrix.
rdcor.mat(x, B = 1)rdcor.mat(x, B = 1)
x |
A numerical matrix. |
B |
The number of permutations to implement to compute the p-value. If B = 1, no p-value is returned. |
The function computes the rank distance correlation matrix and optionally performs permutation-based hypothesis testing.
A list including:
r |
The rank distance correlation matrix. |
pvalue |
A matrix with the associated p-values, if B>1, otherwise NULL. |
Michail Tsagris and Nikolaos Kontemeniotis .
R implementation and documentation: Michail Tsagris [email protected].
Shi H., Drton M. and Han F. (2022). Distribution-free consistent independence tests via center-outward ranks and signs. Journal of the American Statistical Association, 117(537): 395–410.
Zhang Q. (2025). On the connections between Chatterjee's correlation and rank distance correlation. Journal of Nonparametric Statistics, 1–18.
x <- as.matrix(iris[, 1:4]) rdcor.mat(x)x <- as.matrix(iris[, 1:4]) rdcor.mat(x)